pub struct Name(/* private fields */);Expand description
Name of a container. A Container name cannot be empty and cannot contain a null bytes because it is used to generated file names etc.. There’s a set of valid characters allowed in container names: ‘0’..=‘9’ | ‘A’..=‘Z’ | ‘a’..=‘z’ | ‘.’ | ‘_’ | ‘-’. The maximum length allowed for a container name is 1024 characters.